@@ -60,7 +60,6 @@
 #endif
 
 int debug;
-char *argv0;
 char *aname = "";
 void fusedispatch(void*);
 Channel *fusechan;
@@ -98,6 +97,12 @@ usage(void)
 void fusereader(void*);
 void watchfd(void*);
 
+int
+threadmaybackground(void)
+{
+	return 1;
+}
+
 void
 threadmain(int argc, char **argv)
 {
