@@ -7,6 +7,8 @@ if [ "x$X11" = "x" ]; then
 		X11=/usr/X11R6
 	elif [ -d /usr/local/X11R6 ]; then
 		X11=/usr/local/X11R6
+	elif [ -d /usr/X11R7 ]; then
+		X11=/usr/X11R7
 	elif [ -d /usr/X ]; then
 		X11=/usr/X
 	elif [ -d /usr/openwin ]; then	# for Sun
@@ -22,7 +24,7 @@ fi
 
 if [ "x$WSYSTYPE" = "x" ]; then
 	if [ "x`uname`" = "xDarwin" ]; then
-		if sw_vers | egrep 'ProductVersion:	(10\.[0-9]\.|10\.1[012])$' >/dev/null; then
+		if sw_vers | $egrep 'ProductVersion:	(10\.[0-9]\.|10\.1[012])$' >/dev/null; then
 			echo 1>&2 'OS X 10.12 and older are not supported'
 			exit 1
 		fi
