@@ -155,6 +155,12 @@ notifyf(void *a, char *s)
 	noted(NDFLT);
 }
 
+int
+threadmaybackground(void)
+{
+	return 1;
+}
+
 void
 threadmain(int argc, char *argv[])
 {
